import {world, system} from "@minecraft/server";
import {ActionFormData, ActionFormResponse} from "@minecraft/server-ui";

const playerIntervals = new Map();
let intervalId;

function startTracking(player) {
    if (playerIntervals.has(player.name)) {
        return;
    }

    const intervalId = system.runInterval(() => {
        const currentPosition = player.location;

        if (player.previousPosition) {
            const previousPosition = player.previousPosition;

            if (
                currentPosition.x !== previousPosition.x ||
                currentPosition.y !== previousPosition.y ||
                currentPosition.z !== previousPosition.z
            ) {
                stopTracking(player);
            }
        }

        player.previousPosition = currentPosition;
    }, 1);

    playerIntervals.set(player.name, intervalId);
}

function stopTracking(player) {
    const intervalId = playerIntervals.get(player.name);

    if (intervalId !== undefined) {
        system.clearRun(intervalId);
        playerIntervals.delete(player.name);
        delete player.previousPosition;

        const welcomeMessage = `§fХочешь поиграть на сервере с §bМодами§f?\n§fЗаходи на сервер §d§lDygers\n§fIP: §bme.dygers.fun\n§fPORT: §b19132`;
        player.runCommandAsync(`tellraw @s {"rawtext":[{"text":"${welcomeMessage}"}]}`);

        let formMessage = "§fЗаходи на сервер с Модами §d§lDygers§r\n";
        formMessage += "§fУ нас есть два разных по тематике сервера\n\n";
        formMessage += "§fГриф сервер - Сервер на котором много разных дополнений которые разукрасят твою игру\n\n";
        formMessage += "§fАнархия сервер - Ванильный сервер с модами, на котором вам предстоит искать чужие базы, учавствовать в аукционах, ходить на мистики и многое другое!\n\n";
        formMessage += "§fIP: §bme.dygers.fun\n§fPORT: §b19132";

        const form = new ActionFormData()
            .title("§d§lDygers")
            .body(formMessage)
            .button("Закрыть форму");
        form.show(player);
    }
}

world.afterEvents.playerSpawn.subscribe((event) => {
    const player = event.player;
    startTracking(player);
});